# Python Tests against the arkouda_server

  * depending on your setup you may need to set `PYTHONPATH` environment variable to find the `arkouda.py` module
  * check the python source for runtime options
  